curl: Multiprotocol data transfer library and utility
=====================================================

Description
-----------

Multiprotocols data transfer library (and utility).

License
-------

"MIT style license" : see file "COPYING" at the root of the source
tarball, explanations at https://curl.haxx.se/docs/copyright.html.


Upstream Contact
----------------

According to the file README at the root of the tarball, contact is done
by mailing https://curl.haxx.se/mail/
